==> pointpos_api-0.0.16.tar.gz: doc/EmployeeApi.md <==
# pointpos_api.api.EmployeeApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createEmployee**](EmployeeApi.md#createEmployee) | **Post** /employee | Create Employee
[**deleteEmployeeByID**](EmployeeApi.md#deleteEmployeeByID) | **Delete** /employee/:id | Delete Employee By ID
[**findEmployee**](EmployeeApi.md#findEmployee) | **Get** /employee | Get Employee List
[**getEmployeeByID**](EmployeeApi.md#getEmployeeByID) | **Get** /employee/:id | Get Employee By ID
[**updateEmployeeByID**](EmployeeApi.md#updateEmployeeByID) | **Put** /employee/:id | Update Employee By ID


# **createEmployee**
> Employee createEmployee(authorization, xAPIKey, body, xPin)

Create Employee

Create Employee

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new Employee(); // Employee | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createEmployee(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling EmployeeApi->createEmployee: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**Employee**](Employee.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Employee**](Employee.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteEmployeeByID**
> deleteEmployeeByID(authorization, xAPIKey, id, xPin)

Delete Employee By ID

Delete Employee By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deleteEmployeeByID(authorization, xAPIKey, id, xPin);
} catch (e) {
    print("Exception when calling EmployeeApi->deleteEmployeeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findEmployee**
> List<Employee> findEmployee(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter)

Get Employee List

Get Employee  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"firstName\"   - \"lastName\"   - \"email\"   - \"phoneNumber\"   - \"roleId\"   - \"pin\"   - \"assignedOutlets\"   - \"description\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findEmployee(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling EmployeeApi->findEmployee: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;firstName\&quot;   - \&quot;lastName\&quot;   - \&quot;email\&quot;   - \&quot;phoneNumber\&quot;   - \&quot;roleId\&quot;   - \&quot;pin\&quot;   - \&quot;assignedOutlets\&quot;   - \&quot;description\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]

### Return type

[**List<Employee>**](Employee.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getEmployeeByID**
> Employee getEmployeeByID(authorization, xAPIKey, id, xPin)

Get Employee By ID

Get Employee By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getEmployeeByID(authorization, xAPIKey, id, xPin);
    print(result);
} catch (e) {
    print("Exception when calling EmployeeApi->getEmployeeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Employee**](Employee.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateEmployeeByID**
> Employee updateEmployeeByID(authorization, xAPIKey, id, body, xPin)

Update Employee By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new Employee(); // Employee | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updateEmployeeByID(authorization, xAPIKey, id, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling EmployeeApi->updateEmployeeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**Employee**](Employee.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Employee**](Employee.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.2.0.tar.gz: doc/EmployeeApi.md <==
# pointpos_api.api.EmployeeApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createEmployee**](EmployeeApi.md#createEmployee) | **Post** /employee | Create Employee
[**deleteEmployeeByID**](EmployeeApi.md#deleteEmployeeByID) | **Delete** /employee/:id | Delete Employee By ID
[**findEmployee**](EmployeeApi.md#findEmployee) | **Get** /employee | Get Employee List
[**getEmployeeByID**](EmployeeApi.md#getEmployeeByID) | **Get** /employee/:id | Get Employee By ID
[**updateEmployeeByID**](EmployeeApi.md#updateEmployeeByID) | **Put** /employee/:id | Update Employee By ID


# **createEmployee**
> Employee createEmployee(authorization, xAPIKey, body, xPin)

Create Employee

Create Employee

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new Employee(); // Employee | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createEmployee(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling EmployeeApi->createEmployee: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**Employee**](Employee.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Employee**](Employee.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteEmployeeByID**
> deleteEmployeeByID(authorization, xAPIKey, id, xPin)

Delete Employee By ID

Delete Employee By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deleteEmployeeByID(authorization, xAPIKey, id, xPin);
} catch (e) {
    print("Exception when calling EmployeeApi->deleteEmployeeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findEmployee**
> List<Employee> findEmployee(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted)

Get Employee List

Get Employee  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'createdAt|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"firstName\"   - \"lastName\"   - \"email\"   - \"phoneNumber\"   - \"roleId\"   - \"pin\"   - \"assignedOutlets\"   - \"description\"   - \"createdAt\"   - \"createdBy\"   - \"updatedAt\"   - \"updatedBy\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 
var withDeleted = true; // bool | Return with deleted resource

try { 
    var result = api_instance.findEmployee(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted);
    print(result);
} catch (e) {
    print("Exception when calling EmployeeApi->findEmployee: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;createdAt|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;firstName\&quot;   - \&quot;lastName\&quot;   - \&quot;email\&quot;   - \&quot;phoneNumber\&quot;   - \&quot;roleId\&quot;   - \&quot;pin\&quot;   - \&quot;assignedOutlets\&quot;   - \&quot;description\&quot;   - \&quot;createdAt\&quot;   - \&quot;createdBy\&quot;   - \&quot;updatedAt\&quot;   - \&quot;updatedBy\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]
 **withDeleted** | **bool**| Return with deleted resource | [optional] [default to false]

### Return type

[**List<Employee>**](Employee.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getEmployeeByID**
> Employee getEmployeeByID(authorization, xAPIKey, id, xPin)

Get Employee By ID

Get Employee By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getEmployeeByID(authorization, xAPIKey, id, xPin);
    print(result);
} catch (e) {
    print("Exception when calling EmployeeApi->getEmployeeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Employee**](Employee.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateEmployeeByID**
> Employee updateEmployeeByID(authorization, xAPIKey, id, body, xPin)

Update Employee By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new EmployeeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new Employee(); // Employee | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updateEmployeeByID(authorization, xAPIKey, id, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling EmployeeApi->updateEmployeeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**Employee**](Employee.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Employee**](Employee.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
